@@ -2,15 +2,15 @@ package DBIx::Schema::Changelog::Action::Constraint;
 
 =head1 NAME
 
-DBIx::Schema::Changelog::Action::Constraint
+DBIx::Schema::Changelog::Action::Constraint - Action handler for constraint
 
 =head1 VERSION
 
-Version 0.1.0
+Version 0.2.0
 
 =cut
 
-our $VERSION = '0.1.0';
+our $VERSION = '0.2.0';
 
 use strict;
 use warnings;
