@@ -1,20 +1,19 @@
 package DBIx::Schema::Changelog::Command::Driver;
+
 =head1 NAME
 
 DBIx::Schema::Changelog::Command::Driver - Create a new driver modul from template for DBIx::Schema::Changelog!
 
 =head1 VERSION
 
-Version 0.1.0
+Version 0.2.0
 
 =cut
 
-our $VERSION = '0.1.0';
+our $VERSION = '0.2.0';
 
-use 5.14.0;
 use strict;
 use warnings FATAL => 'all';
-use Data::Dumper;
 use Moose;
 use File::Path qw( mkpath );
 
@@ -22,9 +21,9 @@ with 'DBIx::Schema::Changelog::Command::Base';
 ############# End of encapsulated class data.      ########################
 
 has file => (
-	isa => 'Str',
-	is => 'ro',
-	default => q~package DBIx::Schema::Changelog::Driver::{0};
+    isa     => 'Str',
+    is      => 'ro',
+    default => q~package DBIx::Schema::Changelog::Driver::{0};
 
 =head1 NAME
 
@@ -40,85 +39,40 @@ use MooseX::Types::Version qw( Ver );
 
 with 'DBIx::Schema::Changelog::Driver';
 
-has min_version => ( 
-    is => 'ro', 
-    isa => Ver,
-    default=> '3.8.7.2'
-); 
-
-has max_version => ( 
-    is => 'ro', 
-    isa => Ver,
-    default=> '0' 
+has commands => (
+    is      => 'ro',
+    isa     => 'HashRef[Str]',
+    default => sub {
+        return {};
+    }
 );
 
-has 'types' => (
-	is      => 'ro',
-	isa     => 'HashRef[Str]',
-	default => sub { return {}; }
+has defaults => (
+    is      => 'ro',
+    isa     => 'HashRef[Str]',
+    default => sub {
+        return {};
+    }
 );
 
-=head1 VERSION
+has types => (
+    is      => 'ro',
+    isa     => 'HashRef[Str]',
+    default => sub {
+        return {};
+    }
+);
 
-Version 0.0001
-
-=cut
-
-our $VERSION = '0.0.0_001';
+sub _min_version { '0' }
 
 =head1 SUBROUTINES/METHODS
 
-=head2 check_version
-
-=cut
-
-sub check_version {
-    my ( $self, $vers ) = @_;
-    die "Unsupported version: ".$self->min_version()." <= $vers <= ".$self->max_version() if (!MooseX::Types::Version->bw($self->min_version(), $self->max_version(), $vers));
-}
-
 =head2 create_changelog_table
 
 =cut
 
 sub create_changelog_table {}
 
-=head2 create_increment
-
-=cut
-
-sub create_increment {}
-
-=head2 drop_table
-
-=cut
-
-sub drop_table {}
-
-=head2 current
-
-=cut
-
-sub current {}
-
-=head2 primarykey
-
-=cut
-
-sub primarykey {}
-
-=head2 drop_column
-
-=cut
-
-sub drop_column {}
-
-=head2 create_view
-
-=cut
-
-sub create_view {}
-
 =head2 generate_unique
 
 =cut
@@ -135,20 +89,8 @@ sub generate_foreign_key {}
 
 =cut
 
-sub create_index {}
-
-=head2 create_index
-
-=cut
-
 sub add_column {}
 
-=head2 add_constraint
-
-=cut
-
-sub add_constraint {}
-
 no Moose;
 __PACKAGE__->meta->make_immutable;
 
@@ -206,28 +148,109 @@ L<http://search.cpan.org/dist/DBIx-Schema-Changelog-Driver-{0}/>
 =cut
 
 sub make {
-	my ( $self, $config ) = @_;
-	die "No author defined!" unless $config->{author};
-	die "No mail address defined!" unless $config->{email};
-	die "No new driver defined!" unless $config->{driver};
-	my $dir = "$config->{dir}/DBIx-Schema-Changelog-Driver-$config->{driver}";
-	mkpath("$dir/lib/DBIx/Schema/Changelog/Driver", 0755);
-	mkpath("$dir/t",0755);
-	#module
-	write_file("$dir/lib/DBIx/Schema/Changelog/Driver/$config->{driver}.pm", replace_spare( $self->file(), [ $config->{driver}, $config->{author}, $config->{email}, $self->year(), '5.14.0']));
-	write_file("$dir/lib/DBIx/Schema/Changelog/Driver/$config->{driver}.pm", replace_spare($self->license(),[$self->year(), $config->{author}]));
-	#auxilary
-	write_file("$dir/README", replace_spare($self->readme(),['Driver', $config->{driver}, $config->{author}, $config->{email}]));
-	write_file("$dir/README", replace_spare($self->license(),[$self->year(), $config->{author}]));
-	write_file("$dir/Makefile.PL", replace_spare($self->makefile(),['Driver', $config->{driver}, $config->{author}, $config->{email}]));
-	write_file("$dir/Build.PL", replace_spare($self->buildfile(),['Driver', $config->{driver}, $config->{author}, $config->{email}]));
-	write_file("$dir/Changes", replace_spare($self->changes(),['Driver', $config->{driver}, $config->{author}, $config->{email}]));
-	#tests
-	write_file("$dir/t/00-load.t", replace_spare($self->t_load(),['Driver', $config->{driver}]));
-	write_file("$dir/t/boilerplate.t", replace_spare($self->t_boilerplate(),['Driver', $config->{driver}]));
-	write_file("$dir/t/manifest.t", replace_spare($self->t_manifest(),[]));
-	write_file("$dir/t/pod-coverage.t", replace_spare($self->t_pod_coverage(),[]));
-	write_file("$dir/t/pod.t", replace_spare($self->t_pod(),[]));
+    my ( $self, $config ) = @_;
+    die "No author defined!"       unless $config->{author};
+    die "No mail address defined!" unless $config->{email};
+    die "No new driver defined!"   unless $config->{driver};
+    my $dir = "$config->{dir}/DBIx-Schema-Changelog-Driver-$config->{driver}";
+    mkpath( "$dir/lib/DBIx/Schema/Changelog/Driver", 0755 );
+    mkpath( "$dir/t",                                0755 );
+
+    #module
+    write_file(
+        File::Spec->catfile(
+            $dir,        'lib',
+            'DBIx',      'Schema',
+            'Changelog', 'Driver',
+            "$config->{driver}.pm"
+        ),
+        replace_spare(
+            $self->file(),
+            [
+                $config->{driver}, $config->{author},
+                $config->{email},  $self->year(),
+                '5.10.0'
+            ]
+        )
+    );
+    write_file(
+        File::Spec->catfile(
+            $dir,        'lib',
+            'DBIx',      'Schema',
+            'Changelog', 'Driver',
+            "$config->{driver}.pm"
+        ),
+        replace_spare( $self->license(), [ $self->year(), $config->{author} ] )
+    );
+
+    write_file(
+        File::Spec->catfile(
+            $dir,        'lib',
+            'DBIx',      'Schema',
+            'Changelog', 'Driver',
+            "$config->{driver}.pm"
+        ),
+        qq~\n=cut\n~
+    );
+
+    #auxilary
+    write_file(
+        "$dir/README.md",
+        replace_spare(
+            $self->readme(),
+            [
+                'Driver', $config->{driver}, $config->{author}, $config->{email}
+            ]
+        )
+    );
+    write_file( "$dir/README.md",
+        replace_spare( $self->license(), [ $self->year(), $config->{author} ] )
+    );
+    write_file(
+        "$dir/Makefile.PL",
+        replace_spare(
+            $self->makefile(),
+            [
+                'Driver',         $config->{driver}, $config->{author},
+                $config->{email}, $VERSION
+            ]
+        )
+    );
+    write_file(
+        "$dir/Build.PL",
+        replace_spare(
+            $self->buildfile(),
+            [
+                'Driver',         $config->{driver}, $config->{author},
+                $config->{email}, $VERSION
+            ]
+        )
+    );
+    write_file(
+        "$dir/Changes",
+        replace_spare(
+            $self->changes(),
+            [
+                'Driver',    $config->{driver},
+                '0.0.0_001', '1970/01/01',
+                $config->{author}
+            ]
+        )
+    );
+
+    #tests
+    write_file( "$dir/t/00-load.t",
+        replace_spare( $self->t_load(), [ 'Driver', $config->{driver} ] ) );
+    write_file(
+        "$dir/t/boilerplate.t",
+        replace_spare(
+            $self->t_boilerplate(), [ 'Driver', $config->{driver} ]
+        )
+    );
+    write_file( "$dir/t/manifest.t", replace_spare( $self->t_manifest(), [] ) );
+    write_file( "$dir/t/pod-coverage.t",
+        replace_spare( $self->t_pod_coverage(), [] ) );
+    write_file( "$dir/t/pod.t", replace_spare( $self->t_pod(), [] ) );
 }
 
 no Moose;
@@ -279,4 +302,4 @@ CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
 CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
 EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-=cut
\ No newline at end of file
+=cut
