@@ -6,13 +6,12 @@ DBIx::Schema::Changelog::File::Yaml - Module for DBIx::Schema::Changelog::File t
 
 =head1 VERSION
 
-Version 0.1.0
+Version 0.2.0
 
 =cut
 
-our $VERSION = '0.1.0';
+our $VERSION = '0.2.0';
 
-use 5.14.0;
 use strict;
 use warnings FATAL => 'all';
 use Moose;
@@ -56,6 +55,16 @@ has ending => (
     default => '.yml',
 );
 
+=head1 SUBROUTINES/METHODS
+
+=over 4
+
+=item load
+
+    Called to load defined Yaml files
+
+=cut
+
 sub load {
     my ( $self, $file ) = @_;
 
@@ -72,6 +81,8 @@ __PACKAGE__->meta->make_immutable;
 
 1;    # End of DBIx::Schema::Changelog::File
 
+=back
+
 =head1 AUTHOR
 
 Mario Zieschang, C<< <mario.zieschang at combase.de> >>
